Stan Math Library: stan/math/prim/mat/fun/quad_form.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

quad_form.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_QUAD_FORM_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_QUAD_FORM_HPP
3
4 #include <boost/utility/enable_if.hpp>
5 #include <boost/type_traits.hpp>
6 #include <stan/math/prim/mat/fun/Eigen.hpp>
7 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
8 #include <stan/math/prim/mat/err/check_square.hpp>
9 #include <stan/math/prim/mat/err/check_symmetric.hpp>
10 #include <stan/math/prim/mat/fun/dot_product.hpp>
11 #include <stan/math/prim/mat/fun/multiply.hpp>
12 #include <stan/math/prim/mat/fun/transpose.hpp>
13
14 namespace stan {
15 namespace math {
19 template<int RA, int CA, int RB, int CB, typename T>
20 inline Eigen::Matrix<T, CB, CB>
21 quad_form(const Eigen::Matrix<T, RA, CA>& A,
22 const Eigen::Matrix<T, RB, CB>& B) {
23 using stan::math::multiply;
24 stan::math::check_square("quad_form", "A", A);
25 stan::math::check_multiplicable("quad_form",
26 "A", A,
27 "B", B);
28 return multiply(stan::math::transpose(B), multiply(A, B));
29 }
30
31 template<int RA, int CA, int RB, typename T>
32 inline T
33 quad_form(const Eigen::Matrix<T, RA, CA>& A,
34 const Eigen::Matrix<T, RB, 1>& B) {
35 using stan::math::multiply;
36 using stan::math::dot_product;
37
38 stan::math::check_square("quad_form", "A", A);
39 stan::math::check_multiplicable("quad_form",
40 "A", A,
41 "B", B);
42 return dot_product(B, multiply(A, B));
43 }
44
45 }
46 }
47
48 #endif
49
multiply.hpp
check_multiplicable.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::multiply
Eigen::Matrix< fvar< T >, R1, C1 > multiply(const Eigen::Matrix< fvar< T >, R1, C1 > &m, const fvar< T > &c)
Definition: multiply.hpp:21
check_symmetric.hpp
transpose.hpp
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
stan::math::dot_product
fvar< T > dot_product(const Eigen::Matrix< fvar< T >, R1, C1 > &v1, const Eigen::Matrix< fvar< T >, R2, C2 > &v2)
Definition: dot_product.hpp:20
dot_product.hpp
Eigen.hpp
stan::math::transpose
Eigen::Matrix< T, C, R > transpose(const Eigen::Matrix< T, R, C > &m)
Definition: transpose.hpp:12
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
stan::math::quad_form
Eigen::Matrix< T, CB, CB > quad_form(const Eigen::Matrix< T, RA, CA > &A, const Eigen::Matrix< T, RB, CB > &B)
Compute B^T A B.
Definition: quad_form.hpp:21
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.